# Pedtools 

This is a set of common tools for pedestrian data analysis
- Congestion Number

## Installation

This package is available on PyPI.

```bash
pip install pedtools
```
## Congestion number
See the paper: https://arxiv.org/abs/2004.01883

## Example usage
